@@ -26,9 +26,7 @@ from upplib.mail_html import *
 # 生成 markdown 的文本
 from upplib.markdown import *
 
-# 临时添加的工具类
-from upplib.temp import *
 # 多线程处理类的数据
 from upplib.multi_thread import *
 
-from upplib.my import *
+from upplib.fun_util import *
