@@ -33,8 +33,15 @@ def query_sls_logs(logstore_name: str = '',
                 .get_logs(GetLogsRequest(c.get('project_name'), logstore_name, start_time, end_time, line=limit, query=query)))
     to_print_file(f"共 {response.get_count()} 条日志:")
     logs = response.get_logs()
-    for log in reversed(logs):
-        to_print_file(clean_up_msg(get_log_msg(log.contents, default_tz=default_tz), clean_up_type=clean_up_msg_type))
+    log_list = []
+    for log in logs:
+        log_list.append(clean_up_msg(get_log_msg(log.contents, default_tz=default_tz), clean_up_type=clean_up_msg_type))
+    log_list.sort()
+    front_log = None
+    for log in log_list:
+        if log != front_log:
+            to_print_file(log)
+        front_log = log
     to_print_file('END__END')
 
 
