@@ -405,11 +405,11 @@ def to_datetime_str(s: Any = None,
         iso_str = r_s.isoformat()
         if '.' not in iso_str:
             # '2025-10-09T10:52:41+08:00'
-            iso_str = iso_str[0:-6] + '.000' + iso_str[-6:]
+            iso_str = iso_str[0:-6] + iso_str[-6:]
         parts = iso_str.split('.')
         time_zone_part = parts[1]
         time_zone_str = tz
-        millisecond_part = time_zone_part[:3]
+        millisecond_part = time_zone_part[:6]
         for a in ['+', '-']:
             if a in time_zone_part:
                 time_zone_str = a + time_zone_part.split(a)[-1]
