@@ -12,7 +12,7 @@ def get_log_msg(contents: dict,
     # time
     # 2025-09-22T03:19:30+07:00
     _time_ = None
-    for k in ['_time_', 'time', '__time___0']:
+    for k in ['_time_', 'time', '__time__']:
         if k in contents and contents[k] != 'null':
             _time_ = to_datetime_str(contents[k], default_tz=default_tz)
             break
@@ -29,8 +29,10 @@ def get_log_msg(contents: dict,
         time_str = ' '.join(str(content).split(' ')[0:2])
         time_1 = to_datetime(time_str, error_is_none=True)
         # content 中, 含有时间，是以时间开头的字符串
-        if time_1 is not None and _time_ is not None:
+        if time_1 is not None:
             content = content[len(time_str):].strip()
+            if _time_ is None:
+                _time_ = to_datetime_str(time_str, default_tz=default_tz)
     return ' '.join(filter(lambda s: s is not None, [_time_, level, content.replace('\n', '\\n').replace('\t', '\\t')]))
 
 
